@@ -2,7 +2,7 @@
 #
 # Author: Natalia B. Bidart <natalia.bidart@canonical.com>
 #
-# Copyright 2010 Canonical Ltd.
+# Copyright 2010-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,21 +15,36 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
-
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Tests for the Ubuntu One credentials management dbus service."""
 
 import logging
 
 from functools import wraps
 
+import dbus.service
+
 from twisted.internet.defer import Deferred, inlineCallbacks
-from ubuntuone.devtools.testcase import DBusTestCase
 from ubuntuone.devtools.handlers import MementoHandler
+from ubuntuone.devtools.testcases.dbus import DBusTestCase
 
 from ubuntuone.platform.credentials import (
     CredentialsError,
     CredentialsManagementTool,
     logger,
+    UI_PARAMS,
 )
 from ubuntuone.platform.credentials.linux import (
     APP_NAME,
@@ -38,12 +53,6 @@ from ubuntuone.platform.credentials.linux import (
     DBUS_BUS_NAME,
     DBUS_CREDENTIALS_IFACE,
     DBUS_CREDENTIALS_PATH,
-    DESCRIPTION,
-    HELP_TEXT_KEY,
-    PING_URL,
-    PING_URL_KEY,
-    TC_URL_KEY,
-    TC_URL,
     TIMEOUT_INTERVAL,
     ubuntu_sso,
 )
@@ -76,8 +85,13 @@ class FakedSSOService(dbus.service.Object):
         def inner(self, *args, **kwargs):
             """Fake a CredentialsError signal."""
             if FakedSSOService.error_dict is not None:
-                self.CredentialsError(FakedSSOService.app_name,
-                                      FakedSSOService.error_dict)
+                if 'error_handler' in kwargs:
+                    error_handler = kwargs['error_handler']
+                    exc = dbus.service.DBusException(FakedSSOService.error_dict)
+                    error_handler(exc)
+                else:
+                    self.CredentialsError(FakedSSOService.app_name,
+                                          FakedSSOService.error_dict)
             else:
                 return f(self, *args, **kwargs)
 
@@ -87,11 +101,12 @@ class FakedSSOService(dbus.service.Object):
         """Decorator to store arguments to check correct calls."""
 
         @wraps(f)
-        def inner(self, app_name, args):
+        def inner(self, app_name, args, **kwargs):
             """Store arguments to check correct calls."""
             self._app_name = app_name
             self._args = args
-            return f(self, app_name, args)
+            self._kwargs = kwargs
+            return f(self, app_name, args, **kwargs)
 
         return inner
 
@@ -131,6 +146,22 @@ class FakedSSOService(dbus.service.Object):
         else:
             self.CredentialsNotFound(FakedSSOService.app_name)
 
+    @store_args
+    @maybe_emit_error
+    @dbus.service.method(dbus_interface=ubuntu_sso.DBUS_CREDENTIALS_IFACE,
+                         in_signature='sa{ss}', out_signature='a{ss}',
+                         async_callbacks=('reply_handler', 'error_handler'))
+    def find_credentials_sync(self, app_name, args,
+                              reply_handler=None, error_handler=None):
+        """Look for the credentials for an application."""
+        creds = self._credentials.get(FakedSSOService.app_name, None)
+        if creds is None:
+            creds = {}
+        if reply_handler is not None:
+            reply_handler(creds)
+        else:
+            return creds
+
     @store_args
     @maybe_emit_error
     @dbus.service.method(dbus_interface=ubuntu_sso.DBUS_CREDENTIALS_IFACE,
@@ -308,6 +339,19 @@ class ArgsTestCase(CredentialsManagementTestCase):
         self.assertEqual(self.sso_server._app_name, APP_NAME)
         self.assertEqual(self.sso_server._args, {})
 
+    @inlineCallbacks
+    def test_find_credentials_sync(self):
+        """The find_credentials_sync method calls ubuntu_sso's method."""
+        d = Deferred()
+        self.proxy.find_credentials_sync(reply_handler=d.callback,
+                                         error_handler=lambda *a: d.errback(a))
+        yield d
+
+        self.assertEqual(self.sso_server._app_name, APP_NAME)
+        self.assertEqual(self.sso_server._args, {})
+        self.assertTrue('reply_handler' in self.sso_server._kwargs)
+        self.assertTrue('error_handler' in self.sso_server._kwargs)
+
     @inlineCallbacks
     def test_clear_credentials(self):
         """The clear_credentials method calls ubuntu_sso's method."""
@@ -340,8 +384,7 @@ class ArgsTestCase(CredentialsManagementTestCase):
         yield d
 
         self.assertEqual(self.sso_server._app_name, APP_NAME)
-        params = {HELP_TEXT_KEY: DESCRIPTION, TC_URL_KEY: TC_URL,
-                  PING_URL_KEY: PING_URL}
+        params = dict(UI_PARAMS)
         params.update(self.args)
         self.assertEqual(self.sso_server._args, params)
 
@@ -354,8 +397,7 @@ class ArgsTestCase(CredentialsManagementTestCase):
         yield d
 
         self.assertEqual(self.sso_server._app_name, APP_NAME)
-        params = {HELP_TEXT_KEY: DESCRIPTION, TC_URL_KEY: TC_URL,
-                  PING_URL_KEY: PING_URL}
+        params = dict(UI_PARAMS)
         params.update(self.args)
         self.assertEqual(self.sso_server._args, params)
 
@@ -381,6 +423,21 @@ class SameAppNoErrorTestCase(CredentialsManagementTestCase):
         yield d
         yield self.do_test()
 
+    @inlineCallbacks
+    def test_find_credentials_sync(self):
+        """The find_credentials_sync method calls ubuntu_sso's method."""
+        yield self.add_credentials()
+
+        def verify(credentials):
+            """Do the check."""
+            self.assertEqual(credentials, FAKED_CREDENTIALS)
+            self.deferred.callback(None)
+
+        error_handler = lambda a: self.deferred.errback(a)
+        self.proxy.find_credentials_sync(reply_handler=verify,
+                                         error_handler=error_handler)
+        yield self.do_test()
+
     @inlineCallbacks
     def test_find_credentials_without_credentials(self):
         """The find_credentials method calls ubuntu_sso's method."""
@@ -568,6 +625,23 @@ class SameAppWithErrorTestCase(SameAppNoErrorTestCase):
         args = ('CredentialsError', verify)
         super(SameAppWithErrorTestCase, self).connect_signals(callback=args)
 
+    @inlineCallbacks
+    def test_find_credentials_sync(self):
+        """The find_credentials_sync method calls ubuntu_sso's method."""
+
+        def verify(error):
+            """Do the check."""
+            try:
+                self.assertEqual(error.args[0], str(self.error_dict))
+            except Exception, e:
+                self.deferred.errback(e)
+            else:
+                self.deferred.callback(None)
+
+        self.proxy.find_credentials_sync(reply_handler=self.deferred.errback,
+                                         error_handler=verify)
+        yield self.do_test()
+
 
 class OtherAppNoErrorTestCase(SameAppNoErrorTestCase):
     """Test case when the app_name is not APP_NAME and there was no error."""
@@ -598,6 +672,9 @@ class OtherAppWithErrorTestCase(OtherAppNoErrorTestCase):
     app_name = APP_NAME * 2
     error_dict = {'error_type': 'Test'}
 
+    def test_find_credentials_sync(self):
+        """This test has no sense for a synchronous method."""
+
 
 class RefCountingTestCase(BaseTestCase):
     """Tests for the CredentialsManagement ref counting."""
@@ -630,6 +707,34 @@ class RefCountingTestCase(BaseTestCase):
 
         return d
 
+    def test_find_credentials_sync(self):
+        """Keep proper track of on going requests."""
+        d = Deferred()
+
+        def verify(*args):
+            """Make the check."""
+            self.assertEqual(self.client.ref_count, 1)
+            d.callback(True)
+
+        self.client.find_credentials_sync(reply_handler=verify,
+                                          error_handler=d.errback)
+        return d
+
+    def test_find_credentials_sync_error(self):
+        """Keep proper track of on going requests."""
+        d = Deferred()
+
+        def verify(*args):
+            """Make the check."""
+            self.assertEqual(self.client.ref_count, 1)
+            d.callback(True)
+
+        self.patch(FakedSSOService, 'error_dict', 'foo')
+        self.client.find_credentials_sync(reply_handler=d.errback,
+                                          error_handler=verify)
+
+        return d
+
     def test_clear_credentials(self):
         """Keep proper track of on going requests."""
         d = Deferred()
