@@ -2,7 +2,7 @@
 # Authors: Facundo Batista <facundo@canonical.com>
 #          Guillermo Gonzalez <guillermo.gonzalez@canonical.com>
 #
-# Copyright 2009-2011 Canonical Ltd.
+# Copyright 2009-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,7 +15,19 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
-
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Tests for the Event Queue."""
 
 import logging
@@ -99,7 +111,6 @@ class BaseFSMonitorTestCase(testcase.BaseTwistedTestCase):
         fsmdir = self.mktemp('fsmdir')
         partials_dir = self.mktemp('partials_dir')
         self.root_dir = self.mktemp('root_dir')
-        self.home_dir = self.mktemp('home_dir')
         self.vm = testcase.FakeVolumeManager(self.root_dir)
         self.tritcask_dir = self.mktemp("tritcask_dir")
         self.db = Tritcask(self.tritcask_dir)
