@@ -1,9 +1,6 @@
+# -*- coding: utf-8 -*-
 #
-# Author: Facundo Batista <facundo@canonical.com>
-# Author: Guillermo Gonzalez <guillermo.gonzalez@canonical.com>
-# Author: Manuel de la Pnea <manuel@canonical.com>
-#
-# Copyright 2009-2011 Canonical Ltd.
+# Copyright 2009-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -16,28 +13,47 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Commong filesystem notifications tests."""
 
 import logging
 import os
-import unittest
 
 from twisted.internet import defer, reactor
+from twisted.trial import unittest
 from ubuntuone.devtools.handlers import MementoHandler
 
-from tests.platform import _GeneralINotifyProcessor
 from contrib.testing.testcase import (
     BaseTwistedTestCase,
     FakeVolumeManager,
     skip_if_win32_missing_fs_event,
 )
-from ubuntuone.platform import remove_file, remove_dir, rename
+from ubuntuone.platform import (
+    remove_file,
+    remove_dir,
+    rename,
+    _GeneralINotifyProcessor,
+)
 from ubuntuone.syncdaemon.tritcask import Tritcask
 from ubuntuone.syncdaemon import (
     event_queue,
     filesystem_manager,
+    filesystem_notifications,
 )
 
+
 class IgnoreFileTests(unittest.TestCase):
     """Tests the ignore files behaviour."""
 
@@ -72,6 +88,17 @@ class IgnoreFileTests(unittest.TestCase):
         self.assertFalse(p.is_ignored("--foo--"))
         self.assertFalse(p.is_ignored("otherstuff"))
 
+    def test_is_ignored_uses_access(self):
+        """Test that the right access function is called."""
+        sample_path = "sample path"
+        calls = []
+        store_call = lambda *args: calls.append(args)
+        self.patch(filesystem_notifications, "access", store_call)
+        self.patch(filesystem_notifications, "path_exists", lambda _: True)
+        p = _GeneralINotifyProcessor(None)
+        p.is_ignored(sample_path)
+        self.assertEqual(calls, [(sample_path,)])
+
 
 class BaseFSMonitorTestCase(BaseTwistedTestCase):
     """Test the structures where we have the path/watch."""
@@ -85,7 +112,6 @@ class BaseFSMonitorTestCase(BaseTwistedTestCase):
         fsmdir = self.mktemp('fsmdir')
         partials_dir = self.mktemp('partials_dir')
         self.root_dir = self.mktemp('root_dir')
-        self.home_dir = self.mktemp('home_dir')
         self.vm = FakeVolumeManager(self.root_dir)
         self.tritcask_dir = self.mktemp("tritcask_dir")
         self.db = Tritcask(self.tritcask_dir)
