@@ -1,7 +1,6 @@
+# -*- encoding: utf-8 -*-
 #
-# Author: Manuel de la Pena <manuel@canonical.com>
-#
-# Copyright 2011 Canonical Ltd.
+# Copyright 2011-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -14,10 +13,26 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
-
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Specific tests for the os_helper on Windows."""
 
+import errno
 import os
+import shutil
+import sys
+import platform
 
 from twisted.internet import defer
 from twisted.trial.unittest import TestCase
@@ -29,7 +44,14 @@ from ntsecuritycon import (
     FILE_GENERIC_READ,
     FILE_GENERIC_WRITE,
 )
+from win32file import (
+    FILE_ATTRIBUTE_NORMAL,
+    FILE_ATTRIBUTE_SYSTEM,
+    GetFileAttributesW,
+    SetFileAttributesW
+)
 
+from ubuntuone.platform.windows import os_helper
 from ubuntuone.platform.windows.os_helper import (
     _set_file_attributes,
     _unicode_to_bytes,
@@ -40,6 +62,7 @@ from ubuntuone.platform.windows.os_helper import (
     assert_windows_path,
     can_write,
     get_syncdaemon_valid_path,
+    get_user_sid,
     get_windows_valid_path,
     normpath,
     set_dir_readwrite,
@@ -50,6 +73,12 @@ from ubuntuone.platform.windows.os_helper import (
 from tests.platform.test_os_helper import OSWrapperTests, WalkTests
 
 
+# ugly trick to stop pylint for complaining about
+# WindowsError on Linux
+if sys.platform != 'win32':
+    WindowsError = Exception
+
+
 def _build_invalid_windows_bytes_name():
     invalid_unicodes = u''.join(WINDOWS_ILLEGAL_CHARS_MAP)
     invalid_filename = 'test_file' + invalid_unicodes.encode('utf8')
@@ -111,6 +140,16 @@ class TestSpecialOSCalls(BaseTwistedTestCase):
             self.assertFalse(LONG_PATH_PREFIX in current_path)
 
 
+class FakeSecurityInfo(object):
+
+    user_sid = 'user_sid'
+
+    # pylint: disable=C0103
+    def GetSecurityDescriptorOwner(self):
+        return self.user_sid
+    # pylint: enable=C0103
+
+
 class TestAccess(BaseTwistedTestCase):
     """Test specific windows implementation access details."""
 
@@ -257,6 +296,24 @@ class TestAccess(BaseTwistedTestCase):
         _set_file_attributes(self.valid_path, groups)
         self.assertTrue(can_write(self.testfile))
 
+    def fake_security_info(self, *args):
+        return FakeSecurityInfo()
+
+    def test_get_user_sid(self):
+        self.patch(os_helper, "GetSecurityInfo", self.fake_security_info)
+        user_sid = get_user_sid()
+        self.assertEqual(user_sid, FakeSecurityInfo.user_sid)
+
+    def test_set_file_attributes_missing_path(self):
+        """Set file attr for a missing file."""
+        groups = [(EVERYONE_SID, FILE_ALL_ACCESS)]
+        # file does not exist.
+        self.patch(os_helper.os.path, 'exists', lambda f: False)
+        exc = self.assertRaises(WindowsError, _set_file_attributes,
+                                self.valid_path, groups)
+        self.assertEqual(errno.ENOENT, exc.errno,
+                        'Errno should be file not found.')
+
 
 class DecoratorsTestCase(TestCase):
     """Test case for all the validators and transformers."""
@@ -346,3 +403,98 @@ class TestIllegalPathsWalk(WalkTests):
             name_transformer=_unicode_to_bytes)
         super(TestIllegalPathsWalk, self).test_top_down(topdown=topdown,
                                                         expected=expected)
+
+
+class TestSystemPaths(TestCase):
+    """Tests related with the system paths."""
+
+    @defer.inlineCallbacks
+    def setUp(self):
+        """Set tests."""
+        yield super(TestSystemPaths, self).setUp()
+        self.system_paths = ['My Music', 'My Pictures']
+        self.dirs = ['One', 'Two', 'Tree']
+        self.files = ['File', 'Second File', 'Last file']
+        self.temp = self.mktemp()
+        self._make_test_files()
+        self.addCleanup(shutil.rmtree, self.temp)
+
+    def _make_test_files(self):
+        """Create the temp test files."""
+
+        # lets make the files for the tests
+        for d in self.dirs:
+            os.makedirs(os.path.join(self.temp, d))
+
+        for s in self.system_paths:
+            path = os.path.join(self.temp, s)
+            os.makedirs(path)
+            self._set_as_system_path(path)
+
+        for f in self.files:
+            path = os.path.join(self.temp, f)
+            with open(path, 'w') as fd:
+                fd.write('Im a test, blame TestSystemPaths!')
+
+    def _set_as_system_path(self, path):
+        """Set a path to have the system attr."""
+        attrs = GetFileAttributesW(path)
+        attrs = attrs | FILE_ATTRIBUTE_SYSTEM
+        SetFileAttributesW(path, attrs)
+
+    def test_os_listdir(self):
+        """Test the list dir."""
+        expected_result = self.dirs + self.files
+        self.assertEqual(sorted(expected_result),
+                sorted(os_helper.listdir(self.temp)))
+
+    def test_os_walk(self):
+        """Test the walk."""
+        expected_dirs = ['One', 'Two', 'Tree']
+        expected_files = ['File', 'Second File', 'Last file']
+        result_dirs = []
+        result_files = []
+        for dirpath, dirs, files in os_helper.walk(self.temp):
+            result_dirs.extend(dirs)
+            result_files.extend(files)
+        self.assertEqual(sorted(expected_dirs), sorted(result_dirs))
+        self.assertEqual(sorted(expected_files), sorted(result_files))
+
+    def test_native_is_system_path_true(self):
+        """Test the function that returns if is a sytem folder."""
+
+        def fake_get_attrs(path):
+            """Fake the GetFileAttributes method."""
+            return FILE_ATTRIBUTE_NORMAL | FILE_ATTRIBUTE_SYSTEM
+
+        self.patch(os_helper, 'GetFileAttributesW', fake_get_attrs)
+        self.assertTrue(os_helper.native_is_system_path(self.temp))
+
+    def test_native_is_system_path_false(self):
+        """Test the function that returns if is a sytem folder."""
+
+        def fake_get_attrs(path):
+            """Fake the GetFileAttributes method."""
+            return FILE_ATTRIBUTE_NORMAL
+
+        self.patch(os_helper, 'GetFileAttributesW', fake_get_attrs)
+        self.assertFalse(os_helper.native_is_system_path(self.temp))
+
+
+class TestIsRoot(TestCase):
+
+    """Tests for the is_root function."""
+
+    def test_isanadmin_called(self):
+        """Test that shell.IsUserAnAdmin is called."""
+        expected = object()
+        self.patch(os_helper.shell, 'IsUserAnAdmin', lambda: expected)
+        actual = os_helper.is_root()
+        self.assertEqual(expected, actual)
+
+    def test_is_root_on_xp(self):
+        """Test that os_helper.is_root always returns False on XP"""
+        expected = False
+        self.patch(platform, "version", "5.1.2600")
+        actual = os_helper.is_root()
+        self.assertEqual(expected, actual)
