@@ -2,7 +2,7 @@
 #
 # Author: Alejandro J. Cura <alecu@canonical.com>
 #
-# Copyright 2011 Canonical Ltd.
+# Copyright 2011-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,6 +15,19 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Tests for the status events aggregator."""
 
 import logging
@@ -250,7 +263,7 @@ class ToggleableNotificationTestCase(TestCase):
     def setUp(self):
         """Initialize this test instance."""
         yield super(ToggleableNotificationTestCase, self).setUp()
-        self.patch(aggregator, "Notification", FakeNotification)
+        self.patch(aggregator.notification, "Notification", FakeNotification)
         self.notification_switch = aggregator.NotificationSwitch()
         self.toggleable = self.notification_switch.get_notification()
 
@@ -865,7 +878,8 @@ class StatusFrontendTestCase(BaseTwistedTestCase):
         n_bytes_written = 100
         deflated_size = 10000
         self.listener.handle_AQ_UPLOAD_FILE_PROGRESS(
-            share_id, node_id, n_bytes_written, deflated_size)
+            share_id=share_id, node_id=node_id,
+            n_bytes_written=n_bytes_written, deflated_size=deflated_size)
         pe = self.status_frontend.aggregator.progress_events
         self.assertEqual(
             [(share_id, node_id, n_bytes_written, deflated_size)], pe,
@@ -875,13 +889,14 @@ class StatusFrontendTestCase(BaseTwistedTestCase):
         """Progress was made on an downloading file."""
         share_id = 'fake_share'
         node_id = 'fake_node'
-        n_bytes_written = 200
+        n_bytes_read = 200
         deflated_size = 20000
         self.listener.handle_AQ_DOWNLOAD_FILE_PROGRESS(
-            share_id, node_id, n_bytes_written, deflated_size)
+            share_id=share_id, node_id=node_id,
+            n_bytes_read=n_bytes_read, deflated_size=deflated_size)
         pe = self.status_frontend.aggregator.progress_events
         self.assertEqual(
-            [(share_id, node_id, n_bytes_written, deflated_size)], pe,
+            [(share_id, node_id, n_bytes_read, deflated_size)], pe,
             "progress_made was not called (exactly once) on aggregator.")
 
     def test_queue_done(self):
@@ -1298,12 +1313,12 @@ class StatusAggregatorTestCase(TestCase):
         """Progress on up and downloads is tracked."""
         share_id = 'fake_share'
         node_id = 'fake_node'
-        n_bytes_written = 200
+        n_bytes = 200
         deflated_size = 100000
         self.aggregator.progress_made(
-            share_id, node_id, n_bytes_written, deflated_size)
+            share_id, node_id, n_bytes, deflated_size)
         self.assertEqual(
-            {(share_id, node_id): (n_bytes_written)},
+            {(share_id, node_id): (n_bytes)},
             self.aggregator.progress)
 
     def test_get_discovery_message(self):
@@ -1578,3 +1593,5 @@ class HundredFeetTestCase(TestCase):
         self.assertEqual(0, len(notifications_shown))
         sf.queue_done()
         self.assertEqual(0, len(notifications_shown))
+
+HundredFeetTestCase.skip = "libindicate-ERROR causes core dump: #922179"
