@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Author: Guillermo Gonzalez <guillermo.gonzalez@canonical.com>
-#
-# Copyright 2009 Canonical Ltd.
+# Copyright 2009-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,6 +13,19 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """ Tests for main.Main class """
 
 import logging
@@ -22,12 +33,13 @@ import os
 
 from twisted.internet import defer, reactor
 from ubuntuone.devtools.handlers import MementoHandler
+from ubuntuone.platform import expand_user
 
 from contrib.testing.testcase import (
     BaseTwistedTestCase, FAKED_CREDENTIALS,
 )
-from tests.platform import setup_main_test, get_main_params
 from ubuntuone.clientdefs import VERSION
+from ubuntuone.logger import NOTE
 from ubuntuone.platform import (
     is_link,
     make_dir,
@@ -38,19 +50,6 @@ from ubuntuone.platform import (
 from ubuntuone.syncdaemon import main as main_mod
 
 
-def _get_main_common_params(testcase):
-    """Return the parameters used by the all platforms."""
-    return dict(root_dir=testcase.root,
-                shares_dir=testcase.shares,
-                data_dir=testcase.data,
-                partials_dir=testcase.partials_dir,
-                host='localhost', port=0,
-                dns_srv=False, ssl=False,
-                mark_interval=60,
-                handshake_timeout=2,
-                oauth_credentials=FAKED_CREDENTIALS)
-
-
 class FakeListener(object):
     """Just an object that will listen something."""
 
@@ -78,10 +77,8 @@ class MainTests(BaseTwistedTestCase):
         self.shares = self.mktemp('shares')
         self.data = self.mktemp('data')
         self.partials_dir = self.mktemp('partials_dir')
-        # perform the extra setup steps according to the platform
-        setup_main_test(self)
 
-        self.patch(main_mod, 'ExternalInterface', FakedExternalInterface)
+        self.patch(main_mod, 'SyncdaemonService', FakedExternalInterface)
         # no event logger by default
         self.patch(main_mod.event_logging, "get_listener", lambda *a: None)
         # no status listener by default
@@ -93,6 +90,18 @@ class MainTests(BaseTwistedTestCase):
         self._logger.addHandler(self.handler)
         self.addCleanup(self._logger.removeHandler, self.handler)
 
+    def _get_main_common_params(self):
+        """Return the parameters used by the all platforms."""
+        return dict(root_dir=self.root,
+                    shares_dir=self.shares,
+                    data_dir=self.data,
+                    partials_dir=self.partials_dir,
+                    host='localhost', port=0,
+                    dns_srv=False, ssl=False,
+                    mark_interval=60,
+                    handshake_timeout=2,
+                    oauth_credentials=FAKED_CREDENTIALS)
+
     def build_main(self, **kwargs):
         """Build and return a Main object.
 
@@ -101,7 +110,7 @@ class MainTests(BaseTwistedTestCase):
 
         """
         # get the params using the platform code to ensure they are correct
-        params = get_main_params(self, _get_main_common_params(self))
+        params = self._get_main_common_params()
         params.update(kwargs)
         m = main_mod.Main(**params)
         self.addCleanup(m.shutdown)
@@ -130,7 +139,7 @@ class MainTests(BaseTwistedTestCase):
     @defer.inlineCallbacks
     def test_shutdown_pushes_sys_quit(self):
         """When shutting down, the SYS_QUIT event is pushed."""
-        params = get_main_params(self, _get_main_common_params(self))
+        params = self._get_main_common_params()
         main = main_mod.Main(**params)
         events = []
         self.patch(main.event_q, 'push',
@@ -267,15 +276,22 @@ class MainTests(BaseTwistedTestCase):
         main = self.build_main()
         self.assertNotIn(main.status_listener, self._get_listeners(main))
 
+    def test_get_homedir(self):
+        """The get_homedir returns the root dir."""
+        self.patch(main_mod, "xdg_home", self.home_dir)
+        expected = expand_user('~')
+        main = self.build_main()
+        self.assertEqual(main.get_homedir(), expected)
+
     def test_get_rootdir(self):
         """The get_rootdir returns the root dir."""
-        expected = os.path.expanduser(os.path.join('~', 'Ubuntu Test One'))
+        expected = expand_user(os.path.join('~', 'Ubuntu Test One'))
         main = self.build_main(root_dir=expected)
         self.assertEqual(main.get_rootdir(), expected)
 
     def test_get_sharesdir(self):
         """The get_sharesdir returns the shares dir."""
-        expected = os.path.expanduser(os.path.join('~', 'Share it to Me'))
+        expected = expand_user(os.path.join('~', 'Share it to Me'))
         main = self.build_main(shares_dir=expected)
         self.assertEqual(main.get_sharesdir(), expected)
 
@@ -290,3 +306,11 @@ class MainTests(BaseTwistedTestCase):
         """Test that the client version is logged."""
         self.build_main()
         self.assertTrue(self.handler.check_info("client version", VERSION))
+
+    def test_mark(self):
+        """Check the MARK logs ok."""
+        main = self.build_main()
+        main.log_mark()
+        shouldlog = ('MARK', "State: 'INIT'", 'queues IDLE', 'connection',
+                     'queue: 0', 'offloaded: 0', 'hash: 0')
+        self.assertTrue(self.handler.check(NOTE, *shouldlog))
