@@ -2,7 +2,7 @@
 #
 # Author: Facundo Batista <facundo@canonical.com>
 #
-# Copyright 2010 Canonical Ltd.
+# Copyright 2010-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,7 +15,19 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
-
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Tests for States."""
 
 from twisted.internet import defer, reactor
@@ -847,58 +859,6 @@ class TestStateManagerEnterExit(Base):
             self.assertFalse(self.aq.queue.active)
 
 
-class TestStateManagerPassToNetworkManager(Base):
-    """All network events should go to NetworkManager."""
-
-    @defer.inlineCallbacks
-    def setUp(self):
-        yield super(TestStateManagerPassToNetworkManager,
-                    self).setUp()
-
-        # put a function in the middle to log calls
-        self.called_events = []
-        orig_on_event = self.sm.connection.on_event
-        def fake_on_event(event):
-            """Log the call and call original."""
-            self.called_events.append(event)
-            orig_on_event(event)
-        self.sm.connection.on_event = fake_on_event
-
-    def _test(self, event):
-        """Generic test method."""
-        cnt = 0
-        for node in self.sm_nodes_ok:
-            cnt += 1
-            self.sm.state = node
-            self.sm.handle_default(event)
-            self.assertEqual(self.called_events, [event]*cnt)
-
-    def test_net_connected(self):
-        """SYS_NET_CONNECTED should go to Connection no matter where."""
-        self._test('SYS_NET_CONNECTED')
-
-    def test_user_connect(self):
-        """SYS_USER_CONNECT should go to Connection no matter where."""
-        self._test('SYS_USER_CONNECT')
-
-    def test_net_disconnected(self):
-        """SYS_NET_DISCONNECTED should go to Connection no matter where."""
-        self._test('SYS_NET_DISCONNECTED')
-
-    def test_user_disconnect(self):
-        """SYS_USER_DISCONNECT should go to Connection no matter where."""
-        self._test('SYS_USER_DISCONNECT')
-
-    def test_connection_lost(self):
-        """SYS_CONNECTION_LOST should go to Connection no matter where."""
-        self._test('SYS_CONNECTION_LOST')
-
-    def test_handshake_timeout(self):
-        """SYS_HANDSHAKE_TIMEOUT should go to Connection no matter where."""
-        self._test('SYS_HANDSHAKE_TIMEOUT')
-
-
-
 class TestStateManagerPassToQueueManager(Base):
     """All queue events should go to QueueManager."""
 
