@@ -3,7 +3,7 @@
 # Authors: Facundo Batista <facundo@canonical.com>
 #          Manuel de la Pena <manuel@canonical.com>
 #
-# Copyright 2009-2011 Canonical Ltd.
+# Copyright 2009-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -16,7 +16,19 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
-
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Module that implements the Filesystem Monitor machinery."""
 
 import logging
@@ -51,14 +63,12 @@ INOTIFY_EVENTS_GENERAL = (
     pyinotify.IN_DELETE |
     pyinotify.IN_MOVED_FROM |
     pyinotify.IN_MOVED_TO |
-    pyinotify.IN_MOVE_SELF
-)
+    pyinotify.IN_MOVE_SELF)
 INOTIFY_EVENTS_ANCESTORS = (
     pyinotify.IN_DELETE |
     pyinotify.IN_MOVED_FROM |
     pyinotify.IN_MOVED_TO |
-    pyinotify.IN_MOVE_SELF
-)
+    pyinotify.IN_MOVE_SELF)
 
 
 def validate_filename(real_func):
@@ -70,8 +80,8 @@ def validate_filename(real_func):
             event.name.decode("utf8")
         except UnicodeDecodeError:
             dirname = event.path.decode("utf8")
-            self.general_processor.invnames_log.info("%s in %r: path %r", event.maskname,
-                                   dirname, event.name)
+            self.general_processor.invnames_log.info("%s in %r: path %r",
+                event.maskname, dirname, event.name)
             self.general_processor.monitor.eq.push('FS_INVALID_NAME',
                                  dirname=dirname, filename=event.name)
         else:
@@ -132,7 +142,8 @@ class _AncestorsINotifyProcessor(pyinotify.ProcessEvent):
 
         # collect the ancestors of all the still subscribed UDFs except
         # the received ones
-        sub_udfs = (u for u in self.monitor.fs.vm.udfs.itervalues() if u.subscribed)
+        sub_udfs = (u for u in self.monitor.fs.vm.udfs.itervalues() \
+                    if u.subscribed)
         udf_remain = set(sub_udfs) - udfs
         ancestors_to_keep = set()
         for udf in udf_remain:
@@ -153,7 +164,7 @@ class _GeneralINotifyProcessor(pyinotify.ProcessEvent):
     def __init__(self, monitor, ignore_config=None):
         # XXX: avoid circular imports
         from ubuntuone.syncdaemon.filesystem_notifications import (
-            GeneralINotifyProcessor
+            GeneralINotifyProcessor,
         )
         self.general_processor = GeneralINotifyProcessor(monitor,
             self.handle_dir_delete, NAME_TRANSLATIONS,
@@ -262,9 +273,9 @@ class _GeneralINotifyProcessor(pyinotify.ProcessEvent):
                             # if the share_id are != push a delete/create
                             m = "Delete because of different shares: %r"
                             self.general_processor.log.info(m, f_path)
-                            self.general_processor.eq_push(evtname+"DELETE",
+                            self.general_processor.eq_push(evtname + "DELETE",
                                                            path=f_path)
-                            self.general_processor.eq_push(evtname+"CREATE",
+                            self.general_processor.eq_push(evtname + "CREATE",
                                                            path=t_path)
                             if not event.dir:
                                 self.general_processor.eq_push(
@@ -272,7 +283,7 @@ class _GeneralINotifyProcessor(pyinotify.ProcessEvent):
                         else:
                             self.general_processor.monitor.inotify_watch_fix(
                                                                 f_path, t_path)
-                            self.general_processor.eq_push(evtname+"MOVE",
+                            self.general_processor.eq_push(evtname + "MOVE",
                                          path_from=f_path, path_to=t_path)
                     elif is_to_forreal:
                         # this is the case of a MOVE from something ignored
@@ -309,7 +320,8 @@ class _GeneralINotifyProcessor(pyinotify.ProcessEvent):
             self.general_processor.push_event(event)
             if not event.dir:
                 t_path = os.path.join(event.path, event.name)
-                self.general_processor.eq_push('FS_FILE_CLOSE_WRITE', path=t_path)
+                self.general_processor.eq_push('FS_FILE_CLOSE_WRITE',
+                    path=t_path)
 
     @validate_filename
     def process_default(self, event):
@@ -318,7 +330,6 @@ class _GeneralINotifyProcessor(pyinotify.ProcessEvent):
             self.release_held_event()
         self.general_processor.push_event(event)
 
-
     def freeze_begin(self, path):
         """Puts in hold all the events for this path."""
         self.general_processor.freeze_begin(path)
