@@ -1,9 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Authors: Manuel de la Pena <manuel@canonical.com>
-#          Alejandro J. Cura <alecu@canonical.com>
-#
-# Copyright 2011 Canonical Ltd.
+# Copyright 2011-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -16,6 +13,19 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Client lib to simplify the ipc client code."""
 
 import logging
@@ -39,27 +49,30 @@ class SyncDaemonClientConnectionError(SyncDaemonClientError):
 
 def remote(function):
     """Decorate the function to make the remote call."""
+
     @wraps(function)
-    def remote_wrapper(*args, **kwargs):
+    def remote_wrapper(self, *args, **kwargs):
         """Return the deferred for the remote call."""
-        fixed_args = args[1:]
-        logger.info('Performing %s as a remote call.', function.func_name)
-        return args[0].remote.callRemote(function.func_name, *fixed_args,
-                                         **kwargs)
+        fname = function.__name__
+        logger.debug('Performing %s as a remote call (%r, %r).',
+                     fname, args, kwargs)
+        return self.remote.callRemote(fname, *args, **kwargs)
+
     return remote_wrapper
 
 
 def signal(function):
     """Decorate a function to perform the signal callback."""
+
     @wraps(function)
-    def callback_wrapper(*args, **kwargs):
+    def callback_wrapper(self, *args, **kwargs):
         """Return the result of the callback if present."""
-        callback = getattr(args[0], function.func_name + '_cb', None)
+        fname = function.__name__
+        function(self, *args, **kwargs)
+        callback = getattr(self, fname + '_cb', None)
         if callback is not None:
-            fixed_args = args[1:]
-            if not kwargs:
-                return callback(*fixed_args)
-            return callback(*fixed_args, **kwargs)
+            return callback(*args, **kwargs)
+
     return callback_wrapper
 
 
@@ -83,7 +96,7 @@ class RemoteClient(object):
 
 
 class RemoteHandler(object, Referenceable):
-    """Represents a handler that can be called so that is called remotely."""
+    """A handler that can be called so that is called remotely."""
 
     def __init__(self, cb):
         """Create a new instance."""
@@ -115,7 +128,7 @@ def callbacks(callbacks_indexes=None, callbacks_names=None):
                     except KeyError:
                         if len(args) >= current_index + 1:
                             fixed_args[current_index] = RemoteHandler(
-                                                            args[current_index])
+                                                        args[current_index])
             fixed_args = tuple(fixed_args)
             return function(*fixed_args, **kwargs)
         return callbacks_wrapper
@@ -143,13 +156,11 @@ class StatusClient(RemoteClient, Referenceable):
         'on_metaqueue_changed',
     ]
 
-    def __init__(self, remote_status):
-        """Creates the instance."""
-        super(StatusClient, self).__init__(remote_status)
-
     @remote
     def current_status(self):
-        """Return the current status of the system, one of: local_rescan,
+        """Return the current status of the system.
+
+        The status can be one of: local_rescan,
         offline, trying_to_connect, server_rescan or online.
         """
 
@@ -157,6 +168,10 @@ class StatusClient(RemoteClient, Referenceable):
     def current_downloads(self):
         """Return a list of files with a download in progress."""
 
+    @remote
+    def free_space(self, vol_id):
+        """Return the free space for the given volume."""
+
     @remote
     def waiting(self):
         """Return a list of the operations in action queue."""
@@ -177,7 +192,7 @@ class StatusClient(RemoteClient, Referenceable):
 
     @remote
     def current_uploads(self):
-        """ return a list of files with a upload in progress """
+        """Return a list of files with a upload in progress."""
 
     @signal
     def on_content_queue_changed(self):
@@ -234,11 +249,7 @@ class EventsClient(RemoteClient, Referenceable):
     __metaclass__ = RemoteMeta
 
     # calls that will be accessible remotely
-    signal_handlers = ['on_event',]
-
-    def __init__(self, remote_events):
-        """Creates the instance."""
-        super(EventsClient, self).__init__(remote_events)
+    signal_handlers = ['on_event']
 
     @remote
     def push_event(self, event_name, args):
@@ -255,11 +266,11 @@ class SyncDaemonClient(RemoteClient, Referenceable):
     __metaclass__ = RemoteMeta
 
     # calls that will be accessible remotely
-    signal_handlers = ['on_root_mismatch', 'on_quota_exceeded']
-
-    def __init__(self, remote_daemon):
-        """Creates the instance."""
-        super(SyncDaemonClient, self).__init__(remote_daemon)
+    signal_handlers = [
+        'on_root_mismatch',
+        'on_quota_exceeded',
+        'on_volumes_changed',
+    ]
 
     @remote
     def connect(self):
@@ -267,32 +278,33 @@ class SyncDaemonClient(RemoteClient, Referenceable):
 
     @remote
     def disconnect(self):
-        """ Disconnect from the server. """
+        """Disconnect from the server."""
+
+    @remote
+    def get_homedir(self):
+        """Return the home dir/mount point."""
 
     @remote
     def get_rootdir(self):
-        """ Returns the root dir/mount point. """
+        """Return the root dir/mount point."""
 
     @remote
     def get_sharesdir(self):
-        """ Returns the shares dir/mount point. """
+        """Return the shares dir/mount point."""
 
     @remote
     def get_sharesdir_link(self):
-        """ Returns the shares dir/mount point. """
+        """Return the shares dir/mount point. """
 
     @callbacks(callbacks_names=[('reply_handler', 2), ('error_handler', 3)])
     @remote
     def wait_for_nirvana(self, last_event_interval,
                          reply_handler=None, error_handler=None):
-        """ call the reply handler when there are no more
-        events or transfers.
-        """
+        """Call the reply handler when there are no more events/transfers."""
 
-    @callbacks(callbacks_names=[('reply_handler', 1), ('error_handler', 2)])
     @remote
     def quit(self, reply_handler=None, error_handler=None):
-        """ shutdown the syncdaemon. """
+        """Shutdown the syncdaemon."""
 
     @remote
     def rescan_from_scratch(self, volume_id):
@@ -306,13 +318,13 @@ class SyncDaemonClient(RemoteClient, Referenceable):
     def on_quota_exceeded(self, volume_dict):
         """Emit QuotaExceeded signal."""
 
+    @signal
+    def on_volumes_changed(self, volumes):
+        """Emit VolumesChanged signal."""
+
 
 class FileSystemClient(RemoteClient):
-    """ An ipc interface to the FileSystem Manager. """
-
-    def __init__(self, remote_fs):
-        """Creates the instance."""
-        super(FileSystemClient, self).__init__(remote_fs)
+    """An ipc interface to the FileSystem Manager."""
 
     @remote
     def get_metadata(self, path):
@@ -351,15 +363,10 @@ class SharesClient(RemoteClient, Referenceable):
         'on_share_unsubscribe_error',
     ]
 
-    def __init__(self, remote_shares):
-        """Create the instance."""
-        super(SharesClient, self).__init__(remote_shares)
-
     @remote
     def get_shares(self):
         """Return a list of dicts, each dict represents a share."""
 
-    @callbacks(callbacks_names=[('reply_handler', 2), ('error_handler', 3)])
     @remote
     def accept_share(self, share_id, reply_handler=None, error_handler=None):
         """Accept a share.
@@ -369,7 +376,6 @@ class SharesClient(RemoteClient, Referenceable):
 
         """
 
-    @callbacks(callbacks_names=[('reply_handler', 2), ('error_handler', 3)])
     @remote
     def reject_share(self, share_id, reply_handler=None, error_handler=None):
         """Reject a share."""
@@ -388,7 +394,7 @@ class SharesClient(RemoteClient, Referenceable):
 
     @remote
     def create_share(self, path, username, name, access_level):
-        """ Share a subtree to the user identified by username.
+        """Share a subtree to the user identified by username.
 
         @param path: that path to share (the root of the subtree)
         @param username: the username to offer the share to
@@ -408,11 +414,12 @@ class SharesClient(RemoteClient, Referenceable):
 
     @remote
     def refresh_shares(self):
-        """ Refresh the share list, requesting it to the server. """
+        """Refresh the share list, requesting it to the server."""
 
     @remote
     def get_shared(self):
-        """ returns a list of dicts, each dict represents a shared share.
+        """Return a list of dicts, each dict represents a shared share.
+
         A share might not have the path set, as we might be still fetching the
         nodes from the server. In this cases the path is ''
         """
@@ -427,11 +434,11 @@ class SharesClient(RemoteClient, Referenceable):
 
     @signal
     def on_share_delete_error(self, share, error):
-        """Emits ShareDeleteError signal."""
+        """Emit ShareDeleteError signal."""
 
     @signal
     def on_share_created(self, share_info):
-        """ emits ShareCreated signal """
+        """Emit ShareCreated signal."""
 
     @signal
     def on_share_create_error(self, share_info, error):
@@ -439,70 +446,56 @@ class SharesClient(RemoteClient, Referenceable):
 
     @signal
     def on_share_answer_response(self, answer_info):
-        """Emits ShareAnswerResponse signal."""
+        """Emit ShareAnswerResponse signal."""
 
     @signal
     def on_new_share(self, share):
-        """Emits NewShare signal."""
+        """Emit NewShare signal."""
 
     @signal
     def on_share_subscribed(self, share):
-        """Emit the ShareSubscribed signal"""
+        """Emit the ShareSubscribed signal."""
 
     @signal
     def on_share_subscribe_error(self, share_id, error):
-        """Emit the ShareSubscribeError signal"""
+        """Emit the ShareSubscribeError signal."""
 
     @signal
     def on_share_unsubscribed(self, share):
-        """Emit the ShareUnSubscribed signal"""
+        """Emit the ShareUnSubscribed signal."""
 
     @signal
     def on_share_unsubscribe_error(self, share_id, error):
-        """Emit the ShareUnSubscribeError signal"""
+        """Emit the ShareUnSubscribeError signal."""
 
 
 class ConfigClient(RemoteClient):
     """The Syncdaemon config/settings ipc interface. """
 
-    def __init__(self, remote_config):
-        """ Creates the instance."""
-        super(ConfigClient, self).__init__(remote_config)
-
-    @callbacks(callbacks_names=[('reply_handler', 1), ('error_handler', 2)])
     @remote
     def get_throttling_limits(self, reply_handler=None, error_handler=None):
         """Get the read/write limit from AQ and return a dict.
-        Returns a dict(download=int, upload=int), if int is -1 the value isn't
+
+        Return a dict(download=int, upload=int), if int is -1 the value isn't
         configured.
-        The values are bytes/second
+        The values are bytes/second.
         """
 
-    @callbacks(callbacks_names=[('reply_handler', 3), ('error_handler', 4)])
     @remote
-    def set_throttling_limits(self, download, upload,
-                         reply_handler=None, error_handler=None):
+    def set_throttling_limits(self, download, upload):
         """Set the read and write limits. The expected values are bytes/sec."""
 
-    @callbacks(callbacks_names=[('reply_handler', 1), ('error_handler', 2)])
     @remote
-    def enable_bandwidth_throttling(self, reply_handler=None,
-                                    error_handler=None):
+    def enable_bandwidth_throttling(self):
         """Enable bandwidth throttling."""
 
-    @callbacks(callbacks_names=[('reply_handler', 1), ('error_handler', 2)])
     @remote
-    def disable_bandwidth_throttling(self, reply_handler=None,
-                                     error_handler=None):
+    def disable_bandwidth_throttling(self):
         """Disable bandwidth throttling."""
 
-    @callbacks(callbacks_names=[('reply_handler', 1), ('error_handler', 2)])
     @remote
-    def bandwidth_throttling_enabled(self, reply_handler=None,
-                                     error_handler=None):
-        """Returns True (actually 1) if bandwidth throttling is enabled and
-        False (0) otherwise.
-        """
+    def bandwidth_throttling_enabled(self):
+        """Return if the bandwidth throttling is enabled."""
 
     @remote
     def udf_autosubscribe_enabled(self):
@@ -530,19 +523,43 @@ class ConfigClient(RemoteClient):
 
     @remote
     def set_files_sync_enabled(self, enabled):
-        """Enable/disable file sync service."""
+        """Enable/disable file sync service.
+
+        DEPRECATED.
+
+        """
 
     @remote
     def files_sync_enabled(self):
         """Return the files_sync_enabled config value."""
 
+    @remote
+    def enable_files_sync(self):
+        """Enable the file sync service."""
+
+    @remote
+    def disable_files_sync(self):
+        """Disable the file sync service."""
+
     @remote
     def autoconnect_enabled(self):
         """Return the autoconnect config value."""
 
+    @remote
+    def enable_autoconnect(self):
+        """Enable the autoconnect config value."""
+
+    @remote
+    def disable_autoconnect(self):
+        """Disable the autoconnect config value."""
+
     @remote
     def set_autoconnect_enabled(self, enabled):
-        """Enable syncdaemon autoconnect."""
+        """Enable syncdaemon autoconnect.
+
+        DEPRECATED.
+
+        """
 
     @remote
     def show_all_notifications_enabled(self):
@@ -574,10 +591,6 @@ class FoldersClient(RemoteClient, Referenceable):
         'on_folder_unsubscribe_error',
     ]
 
-    def __init__(self, remote_folders):
-        """Creates the instance."""
-        super(FoldersClient, self).__init__(remote_folders)
-
     @remote
     def create(self, path):
         """Create a user defined folder in the specified path."""
@@ -586,6 +599,10 @@ class FoldersClient(RemoteClient, Referenceable):
     def delete(self, folder_id):
         """Delete the folder specified by folder_id"""
 
+    @remote
+    def validate_path(self, path):
+        """Return True if the path is valid for a folder"""
+
     @remote
     def get_folders(self):
         """Return the list of folders (a list of dicts)"""
@@ -600,7 +617,7 @@ class FoldersClient(RemoteClient, Referenceable):
 
     @remote
     def get_info(self, path):
-        """Returns a dict containing the folder information."""
+        """Return a dict containing the folder information."""
 
     @remote
     def refresh_volumes(self):
@@ -652,9 +669,6 @@ class PublicFilesClient(RemoteClient, Referenceable):
         'on_public_files_list_error',
     ]
 
-    def __init__(self, remote_public_files):
-        super(PublicFilesClient, self).__init__(remote_public_files)
-
     @remote
     def change_public_access(self, share_id, node_id, is_public):
         """Change the public access of a file."""
@@ -667,12 +681,11 @@ class PublicFilesClient(RemoteClient, Referenceable):
         """
 
     @signal
-    def on_public_access_changed(self, share_id, node_id, is_public,
-                                   public_url):
+    def on_public_access_changed(self, file_info):
         """Emit the PublicAccessChanged signal."""
 
     @signal
-    def on_public_access_change_error(self, share_id, node_id, error):
+    def on_public_access_change_error(self, file_info, error):
         """Emit the PublicAccessChangeError signal."""
 
     @signal
@@ -683,6 +696,7 @@ class PublicFilesClient(RemoteClient, Referenceable):
     def on_public_files_list_error(self, error):
         """Emit the PublicFilesListError signal."""
 
+
 class UbuntuOneClient(object):
     """Root object that provides access to all the remote objects."""
 
