@@ -1,8 +1,6 @@
 # ubuntuone.syncdaemon.config - SyncDaemon config utilities
 #
-# Author: Guillermo Gonzalez <guillermo.gonzalez@canonical.com>
-#
-# Copyright 2009 Canonical Ltd.
+# Copyright 2009-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,6 +13,19 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """SyncDaemon config"""
 
 from __future__ import with_statement
@@ -25,14 +36,16 @@ import logging
 
 from ConfigParser import NoOptionError, NoSectionError
 from optparse import OptionParser
-from ubuntuone.platform import path_exists, rename
 from ubuntu_sso.xdg_base_directory import (
     load_config_paths,
+    native_path,
     save_config_path,
     xdg_data_home,
     xdg_cache_home,
 )
 
+from ubuntuone.platform import expand_user
+
 # the try/except is to work with older versions of configglue (that
 # had everything that is now configglue.inischema.* as configglue.*).
 # The naming shenanigans are to work around pyflakes being completely
@@ -70,7 +83,8 @@ MAIN = '__main__'
 logger = logging.getLogger('ubuntuone.SyncDaemon.config')
 
 # get (and possibly create if don't exists) the user config file
-_user_config_path = os.path.join(save_config_path('ubuntuone'), CONFIG_FILE)
+_user_config_path = os.path.join(native_path(save_config_path('ubuntuone')),
+                                 CONFIG_FILE)
 
 # module private config instance.
 # this object is the shared config
@@ -85,7 +99,8 @@ def home_dir_parser(value):
     Return the path using user home + value.
 
     """
-    result = os.path.expanduser(path_from_unix(value))
+    path = path_from_unix(value)
+    result = expand_user(path)
     assert isinstance(result, str)
     return result
 
@@ -151,12 +166,13 @@ def get_config_files():
     """
     config_files = []
     for xdg_config_dir in load_config_paths('ubuntuone'):
+        xdg_config_dir = native_path(xdg_config_dir)
         config_file = os.path.join(xdg_config_dir, CONFIG_FILE)
-        if path_exists(config_file):
+        if os.path.exists(config_file):
             config_files.append(config_file)
 
         config_logs = os.path.join(xdg_config_dir, CONFIG_LOGS)
-        if path_exists(config_logs):
+        if os.path.exists(config_logs):
             config_files.append(config_logs)
 
     # reverse the list as load_config_paths returns the user dir first
@@ -164,11 +180,11 @@ def get_config_files():
     # if we are running from a branch, get the config files from it too
     config_file = os.path.join(os.path.dirname(__file__), os.path.pardir,
                                os.path.pardir, 'data', CONFIG_FILE)
-    if path_exists(config_file):
+    if os.path.exists(config_file):
         config_files.append(config_file)
 
     config_logs = os.path.join('data', CONFIG_LOGS)
-    if path_exists(config_logs):
+    if os.path.exists(config_logs):
         config_files.append(config_logs)
 
     return config_files
@@ -287,15 +303,21 @@ class _Config(SyncDaemonConfigParser):
 
     def save(self):
         """Save the config object to disk"""
+        # We should not use standard functions from os_helper here,
+        # because the configglue superclasses do not use them.
+        # Instead, all paths used in this module should be "native",
+        # that is: utf-8 str on linux, or (unicode or mbcs str) on windows
+        from ubuntuone.platform import native_rename
+
         # cleanup empty sections
         for section in [MAIN, THROTTLING, NOTIFICATIONS]:
             if self.has_section(section) and not self.options(section):
                 self.remove_section(section)
         with open(self.config_file + '.new', 'w') as fp:
             self.write(fp)
-        if path_exists(self.config_file):
-            rename(self.config_file, self.config_file + '.old')
-        rename(self.config_file + '.new', self.config_file)
+        if os.path.exists(self.config_file):
+            native_rename(self.config_file, self.config_file + '.old')
+        native_rename(self.config_file + '.new', self.config_file)
 
     def get_parsed(self, section, option):
         """get that fallbacks to our custom defaults"""
@@ -409,6 +431,16 @@ class _Config(SyncDaemonConfigParser):
         """Set the maximum payload size."""
         self.set(MAIN, 'max_payload_size', str(value))
 
+    @requires_section(MAIN)
+    def get_memory_pool_limit(self):
+        """Get the memory pool limit."""
+        return self.get_parsed(MAIN, 'memory_pool_limit')
+
+    @requires_section(MAIN)
+    def set_memory_pool_limit(self, value):
+        """Set the memory pool limit."""
+        self.set(MAIN, 'memory_pool_limit', str(value))
+
     @requires_section(NOTIFICATIONS)
     def set_show_all_notifications(self, enabled):
         self.set(NOTIFICATIONS, 'show_all_notifications', str(enabled))
@@ -419,14 +451,13 @@ class _Config(SyncDaemonConfigParser):
         return self.get_parsed(NOTIFICATIONS, 'show_all_notifications')
 
 
-
 def configglue(fileobj, *filenames, **kwargs):
     """Populate an OptionParser with options and defaults taken from a
     series of files.
 
     @param fileobj: An INI file, as a file-like object.
     @param filenames: An optional series of filenames to merge.
-    @param kwargs: options passed on to the OptionParser constructor except for:
+    @param kwargs: options passed on to the OptionParser constructor except for
     @param args: parse these args (defaults to sys.argv[1:])
     """
     cp = SyncDaemonConfigParser()
@@ -474,4 +505,3 @@ def configglue(fileobj, *filenames, **kwargs):
     config = get_user_config(config_files=config_files)
     config.override_options(overridden)
     return op, options, args
-
