@@ -1,8 +1,6 @@
-# ubuntuone.syncdaemon.local_rescan - local rescanning
+# -*- coding: utf-8 -*-
 #
-# Author: Facundo Batista <facundo@canonical.com>
-#
-# Copyright 2009-2011 Canonical Ltd.
+# Copyright 2009-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,6 +13,19 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Module that implements the Local Rescan."""
 
 import collections
@@ -25,6 +36,10 @@ import os
 import stat
 
 from ubuntuone.syncdaemon import volume_manager
+from ubuntuone.syncdaemon.volume_manager import (
+    ACCESS_LEVEL_RO,
+    ACCESS_LEVEL_RW,
+)
 from ubuntuone.syncdaemon.filesystem_manager import get_stat
 from twisted.internet import defer, reactor
 
@@ -59,7 +74,7 @@ log_warning = functools.partial(lr_logger.log, logging.WARNING)
 def is_valid_name(path):
     """Tell if the name is valid.
 
-    This checks for the bytes in the path to be UTF8 valid before let them
+    This checks for the bytes in the path to be utf-8 valid before let them
     get into Syncdaemon.
 
     There is a similar check in platform/linux/filesystem_notification.py; we
@@ -69,7 +84,7 @@ def is_valid_name(path):
     local rescan.
     """
     try:
-        path.decode("utf8")
+        path.decode("utf-8")
     except UnicodeDecodeError:
         return False
     else:
@@ -97,7 +112,8 @@ class LocalRescan(object):
         for vol in to_scan:
             # check that the path exists in disk
             if not path_exists(vol.path):
-                log_warning('Volume dissapeared: %r - %r', vol.volume_id, vol.path)
+                log_warning('Volume dissapeared: %r - %r',
+                    vol.volume_id, vol.path)
                 if isinstance(vol, volume_manager.Share):
                     log_debug('Removing %r metadata', vol.volume_id)
                     self.vm.share_deleted(vol.volume_id)
@@ -181,14 +197,16 @@ class LocalRescan(object):
         # to avoid the lookups in the nested for
         changed = self.fsm.changed
         CHANGED_SERVER = self.fsm.CHANGED_SERVER
-        for share in self._get_volumes(all_volumes=False, access_level="View"):
+        for share in self._get_volumes(all_volumes=False,
+                                       access_level=ACCESS_LEVEL_RO):
             for mdobj in self.fsm.get_mdobjs_by_share_id(share.id):
                 if changed(mdid=mdobj.mdid) == CHANGED_SERVER:
                     fullname = os.path.join(share.path, mdobj.path)
                     if mdobj.is_dir:
                         # old state, no sense now with generations
                         # but required for the migration path.
-                        log_warning("Found a directory in SERVER: %r", fullname)
+                        log_warning("Found a directory in SERVER: %r",
+                            fullname)
                         mdobj = self.fsm.get_by_path(fullname)
                         self.fsm.set_by_mdid(mdobj.mdid,
                                              server_hash=mdobj.local_hash)
@@ -203,10 +221,10 @@ class LocalRescan(object):
             m = "Broken node: volume_id=%r node_id=%r mdid=%r path=%r"
             log_info(m, mdobj.share_id, mdobj.node_id, mdobj.mdid, mdobj.path)
 
-    def _get_volumes(self, all_volumes=True, access_level='Modify'):
+    def _get_volumes(self, all_volumes=True, access_level=ACCESS_LEVEL_RW):
         """Get all the shares and udfs matching access_level to compare."""
-        modify = access_level == 'Modify'
-        view = access_level == 'View'
+        modify = access_level == ACCESS_LEVEL_RW
+        view = access_level == ACCESS_LEVEL_RO
         for volume in self.vm.get_volumes(all_volumes=all_volumes):
             if (modify and volume.can_write()) or \
                (view and not volume.can_write()):
@@ -223,7 +241,7 @@ class LocalRescan(object):
         else:
             # not in RW shares; let's check RO shares, otherwise it's an error
 
-            for share in self._get_volumes(access_level="View"):
+            for share in self._get_volumes(access_level=ACCESS_LEVEL_RO):
                 if direct.startswith(share.path):
                     return
             log_error("The received path is not in any share!")
@@ -281,7 +299,7 @@ class LocalRescan(object):
                     udf_ok = yield self.eq.add_watches_to_udf_ancestors(volume)
                     if not udf_ok:
                         # we need to ensure that the udf is not subscribed
-                        # when an error happens while adding the parent watches.
+                        # when an error happens while adding the parent watches
                         m = "Unsubscribing UDF %r because not in disk: %r"
                         log_info(m, volume.volume_id, volume.path)
                         self.vm.unsubscribe_udf(volume.volume_id)
@@ -345,19 +363,16 @@ class LocalRescan(object):
     def _resume_download(self, fullname):
         """Resume an interrupted download."""
         mdobj = self.fsm.get_by_path(fullname)
-        fh_factory = lambda: self.fsm.get_partial_for_writing(mdobj.node_id,
-                                                              mdobj.share_id)
         self.aq.download(mdobj.share_id, mdobj.node_id,
-                         mdobj.server_hash, fullname, fh_factory)
+                         mdobj.server_hash, fullname)
 
     def _resume_upload(self, fullname):
         """Resume an interrupted upload."""
         mdobj = self.fsm.get_by_path(fullname)
-        fh_factory = lambda: self.fsm.open_file(mdobj.mdid)
         upload_id = getattr(mdobj, 'upload_id', None)
         self.aq.upload(mdobj.share_id, mdobj.node_id, mdobj.server_hash,
                        mdobj.local_hash, mdobj.crc32, mdobj.size,
-                       fullname, fh_factory, upload_id=upload_id)
+                       fullname, upload_id=upload_id)
 
     def check_stat(self, fullname, oldstat):
         """Check stat info and return if different.
@@ -468,7 +483,6 @@ class LocalRescan(object):
                 log_debug("comp yield: directory %r is new!", fullname)
                 events.append(('FS_DIR_CREATE', fullname))
 
-
         # check all files
         for fname in filenames:
             fullname = os.path.join(dirpath, fname)
@@ -523,7 +537,6 @@ class LocalRescan(object):
                 # otherwise it will never get "empty" to the server
                 events.append(('FS_FILE_CLOSE_WRITE', fullname))
 
-
         # all these don't exist anymore
         for name, (is_dir, statinfo, changed) in shouldbe.iteritems():
             fullname = os.path.join(dirpath, name)
@@ -542,7 +555,8 @@ class LocalRescan(object):
                 to_inform = []
 
                 # get all the info inside that dir
-                objs = self.fsm.get_mdobjs_by_share_id(share.volume_id, fullname)
+                objs = self.fsm.get_mdobjs_by_share_id(share.volume_id,
+                    fullname)
                 for obj in objs:
                     shrpath = obj.path
                     qparts = len(shrpath.split(os.path.sep))
@@ -642,7 +656,7 @@ class LocalRescan(object):
                     log_info("Ignoring path as it's a symlink: %r", fullname)
                     continue
                 if not is_valid_name(fullname):
-                    m = "Ignoring path because it's invalid (non utf8): %r"
+                    m = "Ignoring path because it's invalid (non utf-8): %r"
                     log_info(m, fullname)
                     continue
                 if not access(fullname):
