@@ -2,7 +2,7 @@
 #
 # Author: Guillermo Gonzalez <guillermo.gonzalez@canonical.com>
 #
-# Copyright 2010 Canonical Ltd.
+# Copyright 2010-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,7 +15,21 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""bitcask-like (row_type,key)/value store."""
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
+"""Bitcask-like (row_type,key)/value store."""
+
 from __future__ import division
 
 import contextlib
@@ -82,6 +96,7 @@ TritcaskEntry = namedtuple('TritcaskEntry', ['crc32', 'tstamp', 'key_sz',
 _HintEntry = namedtuple('_HintEntry', ['tstamp', 'key_sz', 'row_type',
                                        'value_sz', 'value_pos', 'key'])
 
+
 class HintEntry(_HintEntry):
     """A entry for the hint file."""
 
@@ -101,6 +116,7 @@ class HintEntry(_HintEntry):
 _KeydirEntry = namedtuple('_KeydirEntry',
                           ['file_id', 'tstamp', 'value_sz', 'value_pos'])
 
+
 class KeydirEntry(_KeydirEntry):
     """A entry for the Keydir."""
 
@@ -267,7 +283,7 @@ class DataFile(object):
         """__getitem__ to support slicing and *only* slicing."""
         if isinstance(item, slice):
             self.fd.seek(item.start)
-            return self.fd.read(item.stop-item.start)
+            return self.fd.read(item.stop - item.start)
         else:
             raise ValueError('Only slice is supported')
 
@@ -277,12 +293,12 @@ class DataFile(object):
         value_sz = len(value)
         tstamp = timestamp()
         header = header_struct.pack(tstamp, key_sz, value_sz, row_type)
-        crc32 = crc32_struct.pack(zlib.crc32(header+key+value))
+        crc32 = crc32_struct.pack(zlib.crc32(header + key + value))
         if EXTRA_SEEK:
             # seek to end of file even if we are in append mode, but py2.x IO
             # in win32 is really buggy, see: http://bugs.python.org/issue3207
             self.fd.seek(0, os.SEEK_END)
-        self.fd.write(crc32+header)
+        self.fd.write(crc32 + header)
         self.fd.write(key)
         value_pos = self.fd.tell()
         self.fd.write(value)
@@ -291,9 +307,9 @@ class DataFile(object):
 
     def read(self, fmmap, current_pos):
         """Read a single entry from the current position."""
-        crc32_bytes = fmmap[current_pos:current_pos+crc32_size]
+        crc32_bytes = fmmap[current_pos:current_pos + crc32_size]
         current_pos += crc32_size
-        header = fmmap[current_pos:current_pos+header_size]
+        header = fmmap[current_pos:current_pos + header_size]
         current_pos += header_size
         if header == '' or crc32_bytes == '':
             # reached EOF
@@ -303,17 +319,17 @@ class DataFile(object):
             tstamp, key_sz, value_sz, row_type = header_struct.unpack(header)
         except struct.error, e:
             raise BadHeader(e)
-        key = fmmap[current_pos:current_pos+key_sz]
+        key = fmmap[current_pos:current_pos + key_sz]
         current_pos += key_sz
         value_pos = current_pos
-        value = fmmap[current_pos:current_pos+value_sz]
+        value = fmmap[current_pos:current_pos + value_sz]
         current_pos += value_sz
         # verify the crc32 of the data
-        if zlib.crc32(header+key+value) == crc32:
+        if zlib.crc32(header + key + value) == crc32:
             return TritcaskEntry(crc32, tstamp, key_sz, value_sz, row_type,
                                  key, value, value_pos), current_pos
         else:
-            raise BadCrc(crc32, zlib.crc32(header+key+value))
+            raise BadCrc(crc32, zlib.crc32(header + key + value))
 
     def get_hint_file(self):
         """Open and return the hint file."""
@@ -421,7 +437,8 @@ class TempDataFile(DataFile):
         new_name = self.filename.replace(self.temp_name, INACTIVE)
         os.rename(self.filename, new_name)
         if self.has_hint:
-            new_hint_name = self.hint_filename.replace(self.temp_name, INACTIVE)
+            new_hint_name = self.hint_filename.replace(self.temp_name,
+                INACTIVE)
             os.rename(self.hint_filename, new_hint_name)
         return ImmutableDataFile(*os.path.split(new_name))
 
@@ -454,13 +471,13 @@ class HintFile(object):
         with contextlib.closing(fmap):
             current_pos = 0
             while True:
-                header = fmap[current_pos:current_pos+hint_header_size]
+                header = fmap[current_pos:current_pos + hint_header_size]
                 current_pos += hint_header_size
                 if header == '':
                     raise StopIteration
                 tstamp, key_sz, row_type, value_sz, value_pos = \
                         hint_header_struct.unpack(header)
-                key = fmap[current_pos:current_pos+key_sz]
+                key = fmap[current_pos:current_pos + key_sz]
                 current_pos += key_sz
                 yield HintEntry(tstamp, key_sz, row_type,
                                 value_sz, value_pos, key)
@@ -600,8 +617,8 @@ class Tritcask(object):
         @param auto_merge: disable auto merge/compaction.
         @param dead_bytes_threshold: the limit factor of dead vs live bytes to
             trigger a merge and/or live file rotation.
-        @param max_immutable_files: the max number of inactive files to use, once
-            this value is reached a merge is triggered.
+        @param max_immutable_files: the max number of inactive files to use,
+            once this value is reached a merge is triggered.
         """
         logger.info("Initializing Tritcask on: %s", path)
         self._keydir = Keydir()
@@ -733,7 +750,7 @@ class Tritcask(object):
                 os.rename(orig, dest)
         # immutable files + live
         logger.info("found %s data files, %s dead and %s broken files",
-                    len(self._immutable)+1, dead_files, broken_files)
+                    len(self._immutable) + 1, dead_files, broken_files)
 
     def rotate(self, create_file=True):
         """Rotate the live file only if it already exsits."""
@@ -806,7 +823,8 @@ class Tritcask(object):
                 self._keydir.remove((entry.row_type, entry.key))
                 # add the tombstone entry to the hint
                 if build_hint:
-                    hint_entry = HintEntry.from_tritcask_entry(entry, dead=True)
+                    hint_entry = HintEntry.from_tritcask_entry(entry,
+                        dead=True)
                     hint_idx[hint_entry.key] = hint_entry
             else:
                 kd_entry = KeydirEntry.from_tritcask_entry(data_file.file_id,
@@ -825,9 +843,9 @@ class Tritcask(object):
         """Get the value for file_id, value_pos."""
         if self.live_file and file_id == self.live_file.file_id:
             # it's the current live file
-            return self.live_file[value_pos:value_pos+value_sz]
+            return self.live_file[value_pos:value_pos + value_sz]
         else:
-            return self._immutable[file_id][value_pos:value_pos+value_sz]
+            return self._immutable[file_id][value_pos:value_pos + value_sz]
 
     def put(self, row_type, key, value):
         """Put key/value in the store."""
@@ -836,7 +854,8 @@ class Tritcask(object):
             raise ValueError('key must be a str instance.')
         if not isinstance(value, str):
             raise ValueError('value must be a str instance.')
-        tstamp, value_pos, value_sz = self.live_file.write(row_type, key, value)
+        tstamp, value_pos, value_sz = self.live_file.write(row_type,
+            key, value)
         if value != TOMBSTONE:
             kd_entry = KeydirEntry(self.live_file.file_id, tstamp,
                                    value_sz, value_pos)
@@ -869,6 +888,7 @@ class Tritcask(object):
     def merge(self, immutable_files):
         """Merge a set of immutable files into a single one."""
         logger.info("Starting merge of %s", immutable_files.keys())
+
         def by_file_id(item):
             file_id = item[1][0]
             return file_id in immutable_files
